Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CpuModule ¶
type CpuModule struct {
// contains filtered or unexported fields
}
func (*CpuModule) Dependencies ¶
type MouseOptions ¶
type MouseOptions struct {
Fg *config.Color `yaml:"fg"`
Bg *config.Color `yaml:"bg"`
Cursor *config.Cursor `yaml:"cursor"`
Tick *config.Duration `yaml:"tick"`
Format *config.Format `yaml:"format"`
}
these field names need to match exactly the ones in Options (coz ya know, reflections ;) kill me. But they do enable cleaner per-module config code so it was worth it. Also Rob Pike is such a goated guy Read his wise words: https://go.dev/blog/laws-of-reflection
type Options ¶
type Options struct {
Fg config.Color `yaml:"fg"`
Bg config.Color `yaml:"bg"`
Cursor config.Cursor `yaml:"cursor"`
Tick config.Duration `yaml:"tick"`
Format config.Format `yaml:"format"`
Threshold ThresholdOptions `yaml:"threshold"`
OnClick config.MouseActions[MouseOptions] `yaml:"onmouse"`
}
Click to show internal directories.
Click to hide internal directories.